# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/agent.proto',
  package='cogmentAPI',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x63ogment/api/agent.proto\x12\ncogmentAPI\x1a\x18\x63ogment/api/common.proto2\xa5\x01\n\x0eServiceActorSP\x12Q\n\x08RunTrial\x12\x1e.cogmentAPI.ActorRunTrialInput\x1a\x1f.cogmentAPI.ActorRunTrialOutput\"\x00(\x01\x30\x01\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_SERVICEACTORSP = _descriptor.ServiceDescriptor(
  name='ServiceActorSP',
  full_name='cogmentAPI.ServiceActorSP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=66,
  serialized_end=231,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunTrial',
    full_name='cogmentAPI.ServiceActorSP.RunTrial',
    index=0,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._ACTORRUNTRIALINPUT,
    output_type=cogment_dot_api_dot_common__pb2._ACTORRUNTRIALOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogmentAPI.ServiceActorSP.Version',
    index=1,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICEACTORSP)

DESCRIPTOR.services_by_name['ServiceActorSP'] = _SERVICEACTORSP

# @@protoc_insertion_point(module_scope)
