# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/common.proto',
  package='cogmentAPI',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x63ogment/api/common.proto\x12\ncogmentAPI\x1a\x19google/protobuf/any.proto\"\x10\n\x0eVersionRequest\"j\n\x0bVersionInfo\x12\x31\n\x08versions\x18\x01 \x03(\x0b\x32\x1f.cogmentAPI.VersionInfo.Version\x1a(\n\x07Version\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x1e\n\x0bTrialConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\x1e\n\x0b\x41\x63torConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"$\n\x11\x45nvironmentConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"9\n\rDatalogParams\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x16\n\x0e\x65xclude_fields\x18\x02 \x03(\t\"z\n\x11\x45nvironmentParams\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\x16\n\x0eimplementation\x18\x03 \x01(\t\x12-\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x1d.cogmentAPI.EnvironmentConfig\"\x83\x01\n\x0b\x41\x63torParams\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tor_class\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x16\n\x0eimplementation\x18\x04 \x01(\t\x12\'\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x17.cogmentAPI.ActorConfig\"\xf0\x01\n\x0bTrialParams\x12-\n\x0ctrial_config\x18\x01 \x01(\x0b\x32\x17.cogmentAPI.TrialConfig\x12*\n\x07\x64\x61talog\x18\x02 \x01(\x0b\x32\x19.cogmentAPI.DatalogParams\x12\x32\n\x0b\x65nvironment\x18\x03 \x01(\x0b\x32\x1d.cogmentAPI.EnvironmentParams\x12\'\n\x06\x61\x63tors\x18\x04 \x03(\x0b\x32\x17.cogmentAPI.ActorParams\x12\x11\n\tmax_steps\x18\x05 \x01(\r\x12\x16\n\x0emax_inactivity\x18\x06 \x01(\r\"/\n\nTrialActor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tor_class\x18\x02 \x01(\t\"B\n\x0bObservation\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"=\n\x06\x41\x63tion\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"o\n\x0cRewardSource\x12\x13\n\x0bsender_name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\'\n\tuser_data\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"j\n\x06Reward\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x15\n\rreceiver_name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x02\x12)\n\x07sources\x18\x04 \x03(\x0b\x32\x18.cogmentAPI.RewardSource\"m\n\x07Message\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x13\n\x0bsender_name\x18\x02 \x01(\t\x12\x15\n\rreceiver_name\x18\x03 \x01(\t\x12%\n\x07payload\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\x91\x02\n\x12\x41\x63torRunTrialInput\x12-\n\x05state\x18\x01 \x01(\x0e\x32\x1e.cogmentAPI.CommunicationState\x12\x33\n\ninit_input\x18\x02 \x01(\x0b\x32\x1d.cogmentAPI.ActorInitialInputH\x00\x12.\n\x0bobservation\x18\x03 \x01(\x0b\x32\x17.cogmentAPI.ObservationH\x00\x12$\n\x06reward\x18\x04 \x01(\x0b\x32\x12.cogmentAPI.RewardH\x00\x12&\n\x07message\x18\x05 \x01(\x0b\x32\x13.cogmentAPI.MessageH\x00\x12\x11\n\x07\x64\x65tails\x18\x06 \x01(\tH\x00\x42\x06\n\x04\x64\x61ta\"\x8a\x02\n\x13\x41\x63torRunTrialOutput\x12-\n\x05state\x18\x01 \x01(\x0e\x32\x1e.cogmentAPI.CommunicationState\x12\x35\n\x0binit_output\x18\x02 \x01(\x0b\x32\x1e.cogmentAPI.ActorInitialOutputH\x00\x12$\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32\x12.cogmentAPI.ActionH\x00\x12$\n\x06reward\x18\x04 \x01(\x0b\x32\x12.cogmentAPI.RewardH\x00\x12&\n\x07message\x18\x05 \x01(\x0b\x32\x13.cogmentAPI.MessageH\x00\x12\x11\n\x07\x64\x65tails\x18\x06 \x01(\tH\x00\x42\x06\n\x04\x64\x61ta\"\x8a\x01\n\x11\x41\x63torInitialInput\x12\x12\n\nactor_name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tor_class\x18\x02 \x01(\t\x12\x11\n\timpl_name\x18\x03 \x01(\t\x12\x10\n\x08\x65nv_name\x18\x04 \x01(\t\x12\'\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x17.cogmentAPI.ActorConfig\"S\n\x12\x41\x63torInitialOutput\x12\x15\n\x0b\x61\x63tor_class\x18\x01 \x01(\tH\x00\x12\x14\n\nactor_name\x18\x02 \x01(\tH\x00\x42\x10\n\x0eslot_selection*a\n\nTrialState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0cINITIALIZING\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0f\n\x0bTERMINATING\x10\x04\x12\t\n\x05\x45NDED\x10\x05*g\n\x12\x43ommunicationState\x12\x15\n\x11UNKNOWN_COM_STATE\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\r\n\tHEARTBEAT\x10\x02\x12\x08\n\x04LAST\x10\x03\x12\x0c\n\x08LAST_ACK\x10\x04\x12\x07\n\x03\x45ND\x10\x05\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_TRIALSTATE = _descriptor.EnumDescriptor(
  name='TrialState',
  full_name='cogmentAPI.TrialState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TERMINATING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENDED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2138,
  serialized_end=2235,
)
_sym_db.RegisterEnumDescriptor(_TRIALSTATE)

TrialState = enum_type_wrapper.EnumTypeWrapper(_TRIALSTATE)
_COMMUNICATIONSTATE = _descriptor.EnumDescriptor(
  name='CommunicationState',
  full_name='cogmentAPI.CommunicationState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_COM_STATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEARTBEAT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAST_ACK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='END', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2237,
  serialized_end=2340,
)
_sym_db.RegisterEnumDescriptor(_COMMUNICATIONSTATE)

CommunicationState = enum_type_wrapper.EnumTypeWrapper(_COMMUNICATIONSTATE)
UNKNOWN = 0
INITIALIZING = 1
PENDING = 2
RUNNING = 3
TERMINATING = 4
ENDED = 5
UNKNOWN_COM_STATE = 0
NORMAL = 1
HEARTBEAT = 2
LAST = 3
LAST_ACK = 4
END = 5



_VERSIONREQUEST = _descriptor.Descriptor(
  name='VersionRequest',
  full_name='cogmentAPI.VersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=83,
)


_VERSIONINFO_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='cogmentAPI.VersionInfo.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cogmentAPI.VersionInfo.Version.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='cogmentAPI.VersionInfo.Version.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=191,
)

_VERSIONINFO = _descriptor.Descriptor(
  name='VersionInfo',
  full_name='cogmentAPI.VersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='versions', full_name='cogmentAPI.VersionInfo.versions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VERSIONINFO_VERSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=191,
)


_TRIALCONFIG = _descriptor.Descriptor(
  name='TrialConfig',
  full_name='cogmentAPI.TrialConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.TrialConfig.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=223,
)


_ACTORCONFIG = _descriptor.Descriptor(
  name='ActorConfig',
  full_name='cogmentAPI.ActorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.ActorConfig.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=255,
)


_ENVIRONMENTCONFIG = _descriptor.Descriptor(
  name='EnvironmentConfig',
  full_name='cogmentAPI.EnvironmentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.EnvironmentConfig.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=293,
)


_DATALOGPARAMS = _descriptor.Descriptor(
  name='DatalogParams',
  full_name='cogmentAPI.DatalogParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogmentAPI.DatalogParams.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_fields', full_name='cogmentAPI.DatalogParams.exclude_fields', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=352,
)


_ENVIRONMENTPARAMS = _descriptor.Descriptor(
  name='EnvironmentParams',
  full_name='cogmentAPI.EnvironmentParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cogmentAPI.EnvironmentParams.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogmentAPI.EnvironmentParams.endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementation', full_name='cogmentAPI.EnvironmentParams.implementation', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.EnvironmentParams.config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=476,
)


_ACTORPARAMS = _descriptor.Descriptor(
  name='ActorParams',
  full_name='cogmentAPI.ActorParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cogmentAPI.ActorParams.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_class', full_name='cogmentAPI.ActorParams.actor_class', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogmentAPI.ActorParams.endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementation', full_name='cogmentAPI.ActorParams.implementation', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.ActorParams.config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=610,
)


_TRIALPARAMS = _descriptor.Descriptor(
  name='TrialParams',
  full_name='cogmentAPI.TrialParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_config', full_name='cogmentAPI.TrialParams.trial_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datalog', full_name='cogmentAPI.TrialParams.datalog', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='cogmentAPI.TrialParams.environment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors', full_name='cogmentAPI.TrialParams.actors', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_steps', full_name='cogmentAPI.TrialParams.max_steps', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_inactivity', full_name='cogmentAPI.TrialParams.max_inactivity', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=853,
)


_TRIALACTOR = _descriptor.Descriptor(
  name='TrialActor',
  full_name='cogmentAPI.TrialActor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cogmentAPI.TrialActor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_class', full_name='cogmentAPI.TrialActor.actor_class', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=902,
)


_OBSERVATION = _descriptor.Descriptor(
  name='Observation',
  full_name='cogmentAPI.Observation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Observation.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.Observation.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.Observation.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=904,
  serialized_end=970,
)


_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='cogmentAPI.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Action.tick_id', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.Action.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.Action.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1033,
)


_REWARDSOURCE = _descriptor.Descriptor(
  name='RewardSource',
  full_name='cogmentAPI.RewardSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='cogmentAPI.RewardSource.sender_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogmentAPI.RewardSource.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='cogmentAPI.RewardSource.confidence', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='cogmentAPI.RewardSource.user_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1146,
)


_REWARD = _descriptor.Descriptor(
  name='Reward',
  full_name='cogmentAPI.Reward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Reward.tick_id', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_name', full_name='cogmentAPI.Reward.receiver_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogmentAPI.Reward.value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='cogmentAPI.Reward.sources', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1254,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='cogmentAPI.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Message.tick_id', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='cogmentAPI.Message.sender_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_name', full_name='cogmentAPI.Message.receiver_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='cogmentAPI.Message.payload', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1365,
)


_ACTORRUNTRIALINPUT = _descriptor.Descriptor(
  name='ActorRunTrialInput',
  full_name='cogmentAPI.ActorRunTrialInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.ActorRunTrialInput.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_input', full_name='cogmentAPI.ActorRunTrialInput.init_input', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observation', full_name='cogmentAPI.ActorRunTrialInput.observation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward', full_name='cogmentAPI.ActorRunTrialInput.reward', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='cogmentAPI.ActorRunTrialInput.message', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='cogmentAPI.ActorRunTrialInput.details', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='cogmentAPI.ActorRunTrialInput.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1368,
  serialized_end=1641,
)


_ACTORRUNTRIALOUTPUT = _descriptor.Descriptor(
  name='ActorRunTrialOutput',
  full_name='cogmentAPI.ActorRunTrialOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.ActorRunTrialOutput.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_output', full_name='cogmentAPI.ActorRunTrialOutput.init_output', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='cogmentAPI.ActorRunTrialOutput.action', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward', full_name='cogmentAPI.ActorRunTrialOutput.reward', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='cogmentAPI.ActorRunTrialOutput.message', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='cogmentAPI.ActorRunTrialOutput.details', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='cogmentAPI.ActorRunTrialOutput.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1644,
  serialized_end=1910,
)


_ACTORINITIALINPUT = _descriptor.Descriptor(
  name='ActorInitialInput',
  full_name='cogmentAPI.ActorInitialInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_name', full_name='cogmentAPI.ActorInitialInput.actor_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_class', full_name='cogmentAPI.ActorInitialInput.actor_class', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='impl_name', full_name='cogmentAPI.ActorInitialInput.impl_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_name', full_name='cogmentAPI.ActorInitialInput.env_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.ActorInitialInput.config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1913,
  serialized_end=2051,
)


_ACTORINITIALOUTPUT = _descriptor.Descriptor(
  name='ActorInitialOutput',
  full_name='cogmentAPI.ActorInitialOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_class', full_name='cogmentAPI.ActorInitialOutput.actor_class', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_name', full_name='cogmentAPI.ActorInitialOutput.actor_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='slot_selection', full_name='cogmentAPI.ActorInitialOutput.slot_selection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2053,
  serialized_end=2136,
)

_VERSIONINFO_VERSION.containing_type = _VERSIONINFO
_VERSIONINFO.fields_by_name['versions'].message_type = _VERSIONINFO_VERSION
_ENVIRONMENTPARAMS.fields_by_name['config'].message_type = _ENVIRONMENTCONFIG
_ACTORPARAMS.fields_by_name['config'].message_type = _ACTORCONFIG
_TRIALPARAMS.fields_by_name['trial_config'].message_type = _TRIALCONFIG
_TRIALPARAMS.fields_by_name['datalog'].message_type = _DATALOGPARAMS
_TRIALPARAMS.fields_by_name['environment'].message_type = _ENVIRONMENTPARAMS
_TRIALPARAMS.fields_by_name['actors'].message_type = _ACTORPARAMS
_REWARDSOURCE.fields_by_name['user_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_REWARD.fields_by_name['sources'].message_type = _REWARDSOURCE
_MESSAGE.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ACTORRUNTRIALINPUT.fields_by_name['state'].enum_type = _COMMUNICATIONSTATE
_ACTORRUNTRIALINPUT.fields_by_name['init_input'].message_type = _ACTORINITIALINPUT
_ACTORRUNTRIALINPUT.fields_by_name['observation'].message_type = _OBSERVATION
_ACTORRUNTRIALINPUT.fields_by_name['reward'].message_type = _REWARD
_ACTORRUNTRIALINPUT.fields_by_name['message'].message_type = _MESSAGE
_ACTORRUNTRIALINPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALINPUT.fields_by_name['init_input'])
_ACTORRUNTRIALINPUT.fields_by_name['init_input'].containing_oneof = _ACTORRUNTRIALINPUT.oneofs_by_name['data']
_ACTORRUNTRIALINPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALINPUT.fields_by_name['observation'])
_ACTORRUNTRIALINPUT.fields_by_name['observation'].containing_oneof = _ACTORRUNTRIALINPUT.oneofs_by_name['data']
_ACTORRUNTRIALINPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALINPUT.fields_by_name['reward'])
_ACTORRUNTRIALINPUT.fields_by_name['reward'].containing_oneof = _ACTORRUNTRIALINPUT.oneofs_by_name['data']
_ACTORRUNTRIALINPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALINPUT.fields_by_name['message'])
_ACTORRUNTRIALINPUT.fields_by_name['message'].containing_oneof = _ACTORRUNTRIALINPUT.oneofs_by_name['data']
_ACTORRUNTRIALINPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALINPUT.fields_by_name['details'])
_ACTORRUNTRIALINPUT.fields_by_name['details'].containing_oneof = _ACTORRUNTRIALINPUT.oneofs_by_name['data']
_ACTORRUNTRIALOUTPUT.fields_by_name['state'].enum_type = _COMMUNICATIONSTATE
_ACTORRUNTRIALOUTPUT.fields_by_name['init_output'].message_type = _ACTORINITIALOUTPUT
_ACTORRUNTRIALOUTPUT.fields_by_name['action'].message_type = _ACTION
_ACTORRUNTRIALOUTPUT.fields_by_name['reward'].message_type = _REWARD
_ACTORRUNTRIALOUTPUT.fields_by_name['message'].message_type = _MESSAGE
_ACTORRUNTRIALOUTPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALOUTPUT.fields_by_name['init_output'])
_ACTORRUNTRIALOUTPUT.fields_by_name['init_output'].containing_oneof = _ACTORRUNTRIALOUTPUT.oneofs_by_name['data']
_ACTORRUNTRIALOUTPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALOUTPUT.fields_by_name['action'])
_ACTORRUNTRIALOUTPUT.fields_by_name['action'].containing_oneof = _ACTORRUNTRIALOUTPUT.oneofs_by_name['data']
_ACTORRUNTRIALOUTPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALOUTPUT.fields_by_name['reward'])
_ACTORRUNTRIALOUTPUT.fields_by_name['reward'].containing_oneof = _ACTORRUNTRIALOUTPUT.oneofs_by_name['data']
_ACTORRUNTRIALOUTPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALOUTPUT.fields_by_name['message'])
_ACTORRUNTRIALOUTPUT.fields_by_name['message'].containing_oneof = _ACTORRUNTRIALOUTPUT.oneofs_by_name['data']
_ACTORRUNTRIALOUTPUT.oneofs_by_name['data'].fields.append(
  _ACTORRUNTRIALOUTPUT.fields_by_name['details'])
_ACTORRUNTRIALOUTPUT.fields_by_name['details'].containing_oneof = _ACTORRUNTRIALOUTPUT.oneofs_by_name['data']
_ACTORINITIALINPUT.fields_by_name['config'].message_type = _ACTORCONFIG
_ACTORINITIALOUTPUT.oneofs_by_name['slot_selection'].fields.append(
  _ACTORINITIALOUTPUT.fields_by_name['actor_class'])
_ACTORINITIALOUTPUT.fields_by_name['actor_class'].containing_oneof = _ACTORINITIALOUTPUT.oneofs_by_name['slot_selection']
_ACTORINITIALOUTPUT.oneofs_by_name['slot_selection'].fields.append(
  _ACTORINITIALOUTPUT.fields_by_name['actor_name'])
_ACTORINITIALOUTPUT.fields_by_name['actor_name'].containing_oneof = _ACTORINITIALOUTPUT.oneofs_by_name['slot_selection']
DESCRIPTOR.message_types_by_name['VersionRequest'] = _VERSIONREQUEST
DESCRIPTOR.message_types_by_name['VersionInfo'] = _VERSIONINFO
DESCRIPTOR.message_types_by_name['TrialConfig'] = _TRIALCONFIG
DESCRIPTOR.message_types_by_name['ActorConfig'] = _ACTORCONFIG
DESCRIPTOR.message_types_by_name['EnvironmentConfig'] = _ENVIRONMENTCONFIG
DESCRIPTOR.message_types_by_name['DatalogParams'] = _DATALOGPARAMS
DESCRIPTOR.message_types_by_name['EnvironmentParams'] = _ENVIRONMENTPARAMS
DESCRIPTOR.message_types_by_name['ActorParams'] = _ACTORPARAMS
DESCRIPTOR.message_types_by_name['TrialParams'] = _TRIALPARAMS
DESCRIPTOR.message_types_by_name['TrialActor'] = _TRIALACTOR
DESCRIPTOR.message_types_by_name['Observation'] = _OBSERVATION
DESCRIPTOR.message_types_by_name['Action'] = _ACTION
DESCRIPTOR.message_types_by_name['RewardSource'] = _REWARDSOURCE
DESCRIPTOR.message_types_by_name['Reward'] = _REWARD
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['ActorRunTrialInput'] = _ACTORRUNTRIALINPUT
DESCRIPTOR.message_types_by_name['ActorRunTrialOutput'] = _ACTORRUNTRIALOUTPUT
DESCRIPTOR.message_types_by_name['ActorInitialInput'] = _ACTORINITIALINPUT
DESCRIPTOR.message_types_by_name['ActorInitialOutput'] = _ACTORINITIALOUTPUT
DESCRIPTOR.enum_types_by_name['TrialState'] = _TRIALSTATE
DESCRIPTOR.enum_types_by_name['CommunicationState'] = _COMMUNICATIONSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQUEST,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.VersionRequest)
  })
_sym_db.RegisterMessage(VersionRequest)

VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {

  'Version' : _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
    'DESCRIPTOR' : _VERSIONINFO_VERSION,
    '__module__' : 'cogment.api.common_pb2'
    # @@protoc_insertion_point(class_scope:cogmentAPI.VersionInfo.Version)
    })
  ,
  'DESCRIPTOR' : _VERSIONINFO,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.VersionInfo)
  })
_sym_db.RegisterMessage(VersionInfo)
_sym_db.RegisterMessage(VersionInfo.Version)

TrialConfig = _reflection.GeneratedProtocolMessageType('TrialConfig', (_message.Message,), {
  'DESCRIPTOR' : _TRIALCONFIG,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialConfig)
  })
_sym_db.RegisterMessage(TrialConfig)

ActorConfig = _reflection.GeneratedProtocolMessageType('ActorConfig', (_message.Message,), {
  'DESCRIPTOR' : _ACTORCONFIG,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorConfig)
  })
_sym_db.RegisterMessage(ActorConfig)

EnvironmentConfig = _reflection.GeneratedProtocolMessageType('EnvironmentConfig', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTCONFIG,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.EnvironmentConfig)
  })
_sym_db.RegisterMessage(EnvironmentConfig)

DatalogParams = _reflection.GeneratedProtocolMessageType('DatalogParams', (_message.Message,), {
  'DESCRIPTOR' : _DATALOGPARAMS,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DatalogParams)
  })
_sym_db.RegisterMessage(DatalogParams)

EnvironmentParams = _reflection.GeneratedProtocolMessageType('EnvironmentParams', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTPARAMS,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.EnvironmentParams)
  })
_sym_db.RegisterMessage(EnvironmentParams)

ActorParams = _reflection.GeneratedProtocolMessageType('ActorParams', (_message.Message,), {
  'DESCRIPTOR' : _ACTORPARAMS,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorParams)
  })
_sym_db.RegisterMessage(ActorParams)

TrialParams = _reflection.GeneratedProtocolMessageType('TrialParams', (_message.Message,), {
  'DESCRIPTOR' : _TRIALPARAMS,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialParams)
  })
_sym_db.RegisterMessage(TrialParams)

TrialActor = _reflection.GeneratedProtocolMessageType('TrialActor', (_message.Message,), {
  'DESCRIPTOR' : _TRIALACTOR,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialActor)
  })
_sym_db.RegisterMessage(TrialActor)

Observation = _reflection.GeneratedProtocolMessageType('Observation', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATION,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Observation)
  })
_sym_db.RegisterMessage(Observation)

Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), {
  'DESCRIPTOR' : _ACTION,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Action)
  })
_sym_db.RegisterMessage(Action)

RewardSource = _reflection.GeneratedProtocolMessageType('RewardSource', (_message.Message,), {
  'DESCRIPTOR' : _REWARDSOURCE,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RewardSource)
  })
_sym_db.RegisterMessage(RewardSource)

Reward = _reflection.GeneratedProtocolMessageType('Reward', (_message.Message,), {
  'DESCRIPTOR' : _REWARD,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Reward)
  })
_sym_db.RegisterMessage(Reward)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Message)
  })
_sym_db.RegisterMessage(Message)

ActorRunTrialInput = _reflection.GeneratedProtocolMessageType('ActorRunTrialInput', (_message.Message,), {
  'DESCRIPTOR' : _ACTORRUNTRIALINPUT,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorRunTrialInput)
  })
_sym_db.RegisterMessage(ActorRunTrialInput)

ActorRunTrialOutput = _reflection.GeneratedProtocolMessageType('ActorRunTrialOutput', (_message.Message,), {
  'DESCRIPTOR' : _ACTORRUNTRIALOUTPUT,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorRunTrialOutput)
  })
_sym_db.RegisterMessage(ActorRunTrialOutput)

ActorInitialInput = _reflection.GeneratedProtocolMessageType('ActorInitialInput', (_message.Message,), {
  'DESCRIPTOR' : _ACTORINITIALINPUT,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorInitialInput)
  })
_sym_db.RegisterMessage(ActorInitialInput)

ActorInitialOutput = _reflection.GeneratedProtocolMessageType('ActorInitialOutput', (_message.Message,), {
  'DESCRIPTOR' : _ACTORINITIALOUTPUT,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorInitialOutput)
  })
_sym_db.RegisterMessage(ActorInitialOutput)


# @@protoc_insertion_point(module_scope)
