# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/hooks.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/hooks.proto',
  package='cogmentAPI',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x63ogment/api/hooks.proto\x12\ncogmentAPI\x1a\x18\x63ogment/api/common.proto\"9\n\x0ePreTrialParams\x12\'\n\x06params\x18\x01 \x01(\x0b\x32\x17.cogmentAPI.TrialParams2\x98\x01\n\x0cTrialHooksSP\x12\x46\n\nOnPreTrial\x12\x1a.cogmentAPI.PreTrialParams\x1a\x1a.cogmentAPI.PreTrialParams\"\x00\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,])




_PRETRIALPARAMS = _descriptor.Descriptor(
  name='PreTrialParams',
  full_name='cogmentAPI.PreTrialParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='cogmentAPI.PreTrialParams.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=122,
)

_PRETRIALPARAMS.fields_by_name['params'].message_type = cogment_dot_api_dot_common__pb2._TRIALPARAMS
DESCRIPTOR.message_types_by_name['PreTrialParams'] = _PRETRIALPARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PreTrialParams = _reflection.GeneratedProtocolMessageType('PreTrialParams', (_message.Message,), {
  'DESCRIPTOR' : _PRETRIALPARAMS,
  '__module__' : 'cogment.api.hooks_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.PreTrialParams)
  })
_sym_db.RegisterMessage(PreTrialParams)



_TRIALHOOKSSP = _descriptor.ServiceDescriptor(
  name='TrialHooksSP',
  full_name='cogmentAPI.TrialHooksSP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=125,
  serialized_end=277,
  methods=[
  _descriptor.MethodDescriptor(
    name='OnPreTrial',
    full_name='cogmentAPI.TrialHooksSP.OnPreTrial',
    index=0,
    containing_service=None,
    input_type=_PRETRIALPARAMS,
    output_type=_PRETRIALPARAMS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogmentAPI.TrialHooksSP.Version',
    index=1,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRIALHOOKSSP)

DESCRIPTOR.services_by_name['TrialHooksSP'] = _TRIALHOOKSSP

# @@protoc_insertion_point(module_scope)
