# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/orchestrator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2
from cogment.api import environment_pb2 as cogment_dot_api_dot_environment__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/orchestrator.proto',
  package='cogmentAPI',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x63ogment/api/orchestrator.proto\x12\ncogmentAPI\x1a\x18\x63ogment/api/common.proto\x1a\x1d\x63ogment/api/environment.proto\"i\n\x11TrialStartRequest\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.cogmentAPI.TrialConfig\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x1a\n\x12trial_id_requested\x18\x03 \x01(\t\"#\n\x0fTrialStartReply\x12\x10\n\x08trial_id\x18\x01 \x01(\t\"1\n\x15TerminateTrialRequest\x12\x18\n\x10hard_termination\x18\x01 \x01(\x08\"\x15\n\x13TerminateTrialReply\"J\n\x10TrialInfoRequest\x12\x1e\n\x16get_latest_observation\x18\x01 \x01(\x08\x12\x16\n\x0eget_actor_list\x18\x02 \x01(\x08\"\xe8\x01\n\tTrialInfo\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12%\n\x05state\x18\x02 \x01(\x0e\x32\x16.cogmentAPI.TrialState\x12\x10\n\x08\x65nv_name\x18\x03 \x01(\t\x12\x0f\n\x07tick_id\x18\x04 \x01(\x04\x12\x16\n\x0etrial_duration\x18\x05 \x01(\x06\x12\x36\n\x12latest_observation\x18\x06 \x01(\x0b\x32\x1a.cogmentAPI.ObservationSet\x12/\n\x0f\x61\x63tors_in_trial\x18\x07 \x03(\x0b\x32\x16.cogmentAPI.TrialActor\"6\n\x0eTrialInfoReply\x12$\n\x05trial\x18\x01 \x03(\x0b\x32\x15.cogmentAPI.TrialInfo\":\n\x10TrialListRequest\x12&\n\x06\x66ilter\x18\x01 \x03(\x0e\x32\x16.cogmentAPI.TrialState\"I\n\x0eTrialListEntry\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12%\n\x05state\x18\x02 \x01(\x0e\x32\x16.cogmentAPI.TrialState2\x91\x03\n\x10TrialLifecycleSP\x12J\n\nStartTrial\x12\x1d.cogmentAPI.TrialStartRequest\x1a\x1b.cogmentAPI.TrialStartReply\"\x00\x12V\n\x0eTerminateTrial\x12!.cogmentAPI.TerminateTrialRequest\x1a\x1f.cogmentAPI.TerminateTrialReply\"\x00\x12J\n\x0cGetTrialInfo\x12\x1c.cogmentAPI.TrialInfoRequest\x1a\x1a.cogmentAPI.TrialInfoReply\"\x00\x12K\n\x0bWatchTrials\x12\x1c.cogmentAPI.TrialListRequest\x1a\x1a.cogmentAPI.TrialListEntry\"\x00\x30\x01\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x32\xa4\x01\n\rClientActorSP\x12Q\n\x08RunTrial\x12\x1f.cogmentAPI.ActorRunTrialOutput\x1a\x1e.cogmentAPI.ActorRunTrialInput\"\x00(\x01\x30\x01\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,cogment_dot_api_dot_environment__pb2.DESCRIPTOR,])




_TRIALSTARTREQUEST = _descriptor.Descriptor(
  name='TrialStartRequest',
  full_name='cogmentAPI.TrialStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.TrialStartRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='cogmentAPI.TrialStartRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_id_requested', full_name='cogmentAPI.TrialStartRequest.trial_id_requested', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=208,
)


_TRIALSTARTREPLY = _descriptor.Descriptor(
  name='TrialStartReply',
  full_name='cogmentAPI.TrialStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogmentAPI.TrialStartReply.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=245,
)


_TERMINATETRIALREQUEST = _descriptor.Descriptor(
  name='TerminateTrialRequest',
  full_name='cogmentAPI.TerminateTrialRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hard_termination', full_name='cogmentAPI.TerminateTrialRequest.hard_termination', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=296,
)


_TERMINATETRIALREPLY = _descriptor.Descriptor(
  name='TerminateTrialReply',
  full_name='cogmentAPI.TerminateTrialReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=319,
)


_TRIALINFOREQUEST = _descriptor.Descriptor(
  name='TrialInfoRequest',
  full_name='cogmentAPI.TrialInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_latest_observation', full_name='cogmentAPI.TrialInfoRequest.get_latest_observation', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_actor_list', full_name='cogmentAPI.TrialInfoRequest.get_actor_list', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=395,
)


_TRIALINFO = _descriptor.Descriptor(
  name='TrialInfo',
  full_name='cogmentAPI.TrialInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogmentAPI.TrialInfo.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.TrialInfo.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_name', full_name='cogmentAPI.TrialInfo.env_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.TrialInfo.tick_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_duration', full_name='cogmentAPI.TrialInfo.trial_duration', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_observation', full_name='cogmentAPI.TrialInfo.latest_observation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors_in_trial', full_name='cogmentAPI.TrialInfo.actors_in_trial', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=630,
)


_TRIALINFOREPLY = _descriptor.Descriptor(
  name='TrialInfoReply',
  full_name='cogmentAPI.TrialInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial', full_name='cogmentAPI.TrialInfoReply.trial', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=686,
)


_TRIALLISTREQUEST = _descriptor.Descriptor(
  name='TrialListRequest',
  full_name='cogmentAPI.TrialListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='cogmentAPI.TrialListRequest.filter', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=746,
)


_TRIALLISTENTRY = _descriptor.Descriptor(
  name='TrialListEntry',
  full_name='cogmentAPI.TrialListEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogmentAPI.TrialListEntry.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.TrialListEntry.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=821,
)

_TRIALSTARTREQUEST.fields_by_name['config'].message_type = cogment_dot_api_dot_common__pb2._TRIALCONFIG
_TRIALINFO.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
_TRIALINFO.fields_by_name['latest_observation'].message_type = cogment_dot_api_dot_environment__pb2._OBSERVATIONSET
_TRIALINFO.fields_by_name['actors_in_trial'].message_type = cogment_dot_api_dot_common__pb2._TRIALACTOR
_TRIALINFOREPLY.fields_by_name['trial'].message_type = _TRIALINFO
_TRIALLISTREQUEST.fields_by_name['filter'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
_TRIALLISTENTRY.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
DESCRIPTOR.message_types_by_name['TrialStartRequest'] = _TRIALSTARTREQUEST
DESCRIPTOR.message_types_by_name['TrialStartReply'] = _TRIALSTARTREPLY
DESCRIPTOR.message_types_by_name['TerminateTrialRequest'] = _TERMINATETRIALREQUEST
DESCRIPTOR.message_types_by_name['TerminateTrialReply'] = _TERMINATETRIALREPLY
DESCRIPTOR.message_types_by_name['TrialInfoRequest'] = _TRIALINFOREQUEST
DESCRIPTOR.message_types_by_name['TrialInfo'] = _TRIALINFO
DESCRIPTOR.message_types_by_name['TrialInfoReply'] = _TRIALINFOREPLY
DESCRIPTOR.message_types_by_name['TrialListRequest'] = _TRIALLISTREQUEST
DESCRIPTOR.message_types_by_name['TrialListEntry'] = _TRIALLISTENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrialStartRequest = _reflection.GeneratedProtocolMessageType('TrialStartRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIALSTARTREQUEST,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialStartRequest)
  })
_sym_db.RegisterMessage(TrialStartRequest)

TrialStartReply = _reflection.GeneratedProtocolMessageType('TrialStartReply', (_message.Message,), {
  'DESCRIPTOR' : _TRIALSTARTREPLY,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialStartReply)
  })
_sym_db.RegisterMessage(TrialStartReply)

TerminateTrialRequest = _reflection.GeneratedProtocolMessageType('TerminateTrialRequest', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATETRIALREQUEST,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TerminateTrialRequest)
  })
_sym_db.RegisterMessage(TerminateTrialRequest)

TerminateTrialReply = _reflection.GeneratedProtocolMessageType('TerminateTrialReply', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATETRIALREPLY,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TerminateTrialReply)
  })
_sym_db.RegisterMessage(TerminateTrialReply)

TrialInfoRequest = _reflection.GeneratedProtocolMessageType('TrialInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIALINFOREQUEST,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialInfoRequest)
  })
_sym_db.RegisterMessage(TrialInfoRequest)

TrialInfo = _reflection.GeneratedProtocolMessageType('TrialInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRIALINFO,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialInfo)
  })
_sym_db.RegisterMessage(TrialInfo)

TrialInfoReply = _reflection.GeneratedProtocolMessageType('TrialInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _TRIALINFOREPLY,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialInfoReply)
  })
_sym_db.RegisterMessage(TrialInfoReply)

TrialListRequest = _reflection.GeneratedProtocolMessageType('TrialListRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIALLISTREQUEST,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialListRequest)
  })
_sym_db.RegisterMessage(TrialListRequest)

TrialListEntry = _reflection.GeneratedProtocolMessageType('TrialListEntry', (_message.Message,), {
  'DESCRIPTOR' : _TRIALLISTENTRY,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialListEntry)
  })
_sym_db.RegisterMessage(TrialListEntry)



_TRIALLIFECYCLESP = _descriptor.ServiceDescriptor(
  name='TrialLifecycleSP',
  full_name='cogmentAPI.TrialLifecycleSP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=824,
  serialized_end=1225,
  methods=[
  _descriptor.MethodDescriptor(
    name='StartTrial',
    full_name='cogmentAPI.TrialLifecycleSP.StartTrial',
    index=0,
    containing_service=None,
    input_type=_TRIALSTARTREQUEST,
    output_type=_TRIALSTARTREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TerminateTrial',
    full_name='cogmentAPI.TrialLifecycleSP.TerminateTrial',
    index=1,
    containing_service=None,
    input_type=_TERMINATETRIALREQUEST,
    output_type=_TERMINATETRIALREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTrialInfo',
    full_name='cogmentAPI.TrialLifecycleSP.GetTrialInfo',
    index=2,
    containing_service=None,
    input_type=_TRIALINFOREQUEST,
    output_type=_TRIALINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchTrials',
    full_name='cogmentAPI.TrialLifecycleSP.WatchTrials',
    index=3,
    containing_service=None,
    input_type=_TRIALLISTREQUEST,
    output_type=_TRIALLISTENTRY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogmentAPI.TrialLifecycleSP.Version',
    index=4,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRIALLIFECYCLESP)

DESCRIPTOR.services_by_name['TrialLifecycleSP'] = _TRIALLIFECYCLESP


_CLIENTACTORSP = _descriptor.ServiceDescriptor(
  name='ClientActorSP',
  full_name='cogmentAPI.ClientActorSP',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1228,
  serialized_end=1392,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunTrial',
    full_name='cogmentAPI.ClientActorSP.RunTrial',
    index=0,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._ACTORRUNTRIALOUTPUT,
    output_type=cogment_dot_api_dot_common__pb2._ACTORRUNTRIALINPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogmentAPI.ClientActorSP.Version',
    index=1,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLIENTACTORSP)

DESCRIPTOR.services_by_name['ClientActorSP'] = _CLIENTACTORSP

# @@protoc_insertion_point(module_scope)
